From: minima <minima>
Date: Sat, 4 Feb 2006 19:33:11 +0000 (+0000)
Subject: check for lower case letters in spotted calls
X-Git-Tag: 1.53~56
X-Git-Url: http://dxspider.org/gitweb/gitweb.cgi?a=commitdiff_plain;h=217ca173cdfac728815e84cd56b897a60e541f64;p=spider.git

check for lower case letters in spotted calls
---

diff --git a/perl/DXProt.pm b/perl/DXProt.pm
index af1f34f7..5c6ca1fb 100644
--- a/perl/DXProt.pm
+++ b/perl/DXProt.pm
@@ -479,11 +479,16 @@ sub handle_11
 	#			return if $rspfcheck and !$self->rspfcheck(1, $_[7], $_[6]);
 	
 	# is the spotted callsign blank? This should really be trapped earlier but it
 	# could break other protocol sentences.
 	if ($_[2] =~ /^\s*$/) {
 		dbg("PCPROT: blank callsign, dropped") if isdbg('chanerr');
 		return;
 	}
+	if ($_[2] =~ /[a-z]/) {
+		dbg("PCPROT: lowercase characters, dropped") if isdbg('chanerr');
+		return;
+	}
+
 
 	# if this is a 'nodx' node then ignore it
 	if ($badnode->in($_[7])) {
@@ -479,11 +479,16 @@ sub handle_11
 	
 	# is the spotted callsign blank? This should really be trapped earlier but it
-	# could break other protocol sentences.
+	# could break other protocol sentences. Also check for lower case characters.
 	if ($_[2] =~ /^\s*$/) {
 		dbg("PCPROT: blank callsign, dropped") if isdbg('chanerr');